PALM-meteo: palmmeteo Namespace Reference

PALM-meteo

Loading...
Searching...
No Matches
Namespaces | Variables
palmmeteo Namespace Reference

## Namespaces
namespace | __main__
namespace | config
namespace | dispatch
namespace | library
namespace | logging
namespace | plugins
namespace | runtime
namespace | utils
namespace | vinterp

## Variables
str | signature = f'PALM-meteo version {__version__}'

## Detailed Description

    PALM-meteo: processor of meteorological input data for the PALM model system.

    Creates PALM dynamic driver from various sources.

## Variable Documentation

## ◆ signature

str palmmeteo.signature = f'PALM-meteo version {__version__}'